==> ldap_auth-2.0.21.zip: ldap_auth/js/ldap_upgrade.js <==
function Instance_Pricing(x, instances_premium, instances_allinclusive) {
  document.getElementById("instances_premium").value = x;
  document.getElementById("instances_allinclusive").value = x;

  var pre_upgradeBtn = jQuery('#pre-upgrade-btn');
  var ent_upgradeBtn = jQuery('#ent-upgrade-btn');

  const price_standard = { 1: "249", 2: "479", 3: "699", 4: "929", 5: "1079", 6: "1279", 7: "1479", 8: "1689", 9: "1899", 10: "2019", 15: "2349", 20: "2649", 30: "2949", 40: "3249", 50: "3349" };
  if(x==='10+'){

    document.getElementById("allinclusive_price").innerHTML = "<br><br><a href=\"https://miniorange.com/contact\" class=\"mo_guide_text-color\" target=\"_blank\">Contact Us</a>";
    document.getElementById("premium_price").innerHTML = "<br><br><a href=\"https://miniorange.com/contact\" class=\"mo_guide_text-color\" target=\"_blank\">Contact Us</a>";

    document.getElementById("premium_discount").style.display = "none";
    document.getElementById("allinclusive_discount").style.display = "none";

    pre_upgradeBtn.hide();
    ent_upgradeBtn.hide();

  }else{
    pre_upgradeBtn.show();
    ent_upgradeBtn.show();

    const price_premium = { 1: "399", 2: "749", 3: "1119", 4: "1419", 5: " 1659", 6: "1899", 7: "2129", 8: "2349", 9: "2499", 10: "2599", 15: "2899", 20: "3199", 30: "3449", 40: "3699", 50: "3899" };
    var actual_price_premium = 399 * x;
    var discount_premium = ((actual_price_premium - price_premium[x]) / actual_price_premium) * 100;
    discount_premium = Math.floor(discount_premium);
    if (discount_premium !== 0) {
      document.getElementById("premium_price").innerHTML = "<sup>$</sup><s style=\"color:red;\" >" + actual_price_premium + "</s>" + price_premium[x];
      document.getElementById("premium_discount").innerHTML = "<div style=\"color:red;\"><b> [ " + discount_premium + " % discount ] </b></div>";
      document.getElementById("premium_discount").style.display = "block";
    }else{
      document.getElementById("premium_price").innerHTML = "<sup>$</sup>" + price_premium[x];
      document.getElementById("premium_discount").style.display = "none";
    }
    const price_allinclusive = { 1: "449", 2: "849", 3: "1249", 4: "1549", 5: "1849", 6: "2099", 7: "2349", 8: "2549", 9: "2749", 10: "2899", 15: "3199", 20: "3499", 30: "3874", 40: "4249", 50: "4624" };
    var actual_price_allinclusive = 449 * x;
    var discount_allinclusive = ((actual_price_allinclusive - price_allinclusive[x]) / actual_price_allinclusive) * 100;
    discount_allinclusive = Math.floor(discount_allinclusive);

    if (discount_allinclusive !== 0){
      document.getElementById("allinclusive_price").innerHTML = "<sup>$</sup><s style=\"color:red;\" >" + actual_price_allinclusive + "</s>" + price_allinclusive[x];
      document.getElementById("allinclusive_discount").innerHTML = "<div style=\"color:red;\"><b>[ " + discount_allinclusive + " % discount ] </b></div>";
      document.getElementById("allinclusive_discount").style.display = "block";
    }else{
      document.getElementById("allinclusive_price").innerHTML = "<sup>$</sup>" + price_allinclusive[x];
      document.getElementById("allinclusive_discount").style.display = "none";
    }
  }

}

var coll = document.getElementsByClassName("collapsible");
var i;

for (i = 0; i < coll.length; i++) {
  coll[i].addEventListener("click", function() {
    this.classList.toggle("active");
    var content = this.nextElementSibling;
    if (content.style.display === "block") {
      content.style.display = "none";
    } else {
      content.style.display = "block";
    }
  });
}

==> ldap_auth-2.0.22.zip: ldap_auth/js/ldap_upgrade.js <==
function Instance_Pricing(x, instances_premium, instances_allinclusive) {
  document.getElementById("instances_premium").value = x;
  document.getElementById("instances_allinclusive").value = x;

  var pre_upgradeBtn = jQuery('#pre-upgrade-btn');
  var ent_upgradeBtn = jQuery('#ent-upgrade-btn');

  const price_standard = { 1: "249", 2: "479", 3: "699", 4: "929", 5: "1079", 6: "1279", 7: "1479", 8: "1689", 9: "1899", 10: "2019", 15: "2349", 20: "2649", 30: "2949", 40: "3249", 50: "3349" };
  if(x==='10+'){

    document.getElementById("allinclusive_price").innerHTML = "<br><br><a href=\"https://miniorange.com/contact\" class=\"mo-enquire-btn\" target=\"_blank\">Contact Support</a>";
    document.getElementById("premium_price").innerHTML = "<br><br><a href=\"https://miniorange.com/contact\" class=\"mo-enquire-btn\" target=\"_blank\">Contact Support</a>";

    document.getElementById("premium_discount").style.display = "none";
    document.getElementById("allinclusive_discount").style.display = "none";

    pre_upgradeBtn.hide();
    ent_upgradeBtn.hide();

  }else{
    pre_upgradeBtn.show();
    ent_upgradeBtn.show();

    const price_premium = { 1: "399", 2: "749", 3: "1119", 4: "1419", 5: " 1659", 6: "1899", 7: "2129", 8: "2349", 9: "2499", 10: "2599", 15: "2899", 20: "3199", 30: "3449", 40: "3699", 50: "3899" };
    var actual_price_premium = 399 * x;
    var discount_premium = ((actual_price_premium - price_premium[x]) / actual_price_premium) * 100;
    discount_premium = Math.floor(discount_premium);
    if (discount_premium !== 0) {
      document.getElementById("premium_price").innerHTML = "<sup>$</sup><s style=\"color:red;\" >" + actual_price_premium + "</s>" + price_premium[x] + " <span class=\"mo-pricing-interval\">per year</span>";
      document.getElementById("premium_discount").innerHTML = "<div style=\"color:red;\"><b> [ " + discount_premium + " % discount ] </b></div>";
      document.getElementById("premium_discount").style.display = "block";
    }else{
      document.getElementById("premium_price").innerHTML = "<sup>$</sup>" + price_premium[x] + " <span class=\"mo-pricing-interval\">per year</span>";
      document.getElementById("premium_discount").style.display = "none";
    }
    const price_allinclusive = { 1: "449", 2: "849", 3: "1249", 4: "1549", 5: "1849", 6: "2099", 7: "2349", 8: "2549", 9: "2749", 10: "2899", 15: "3199", 20: "3499", 30: "3874", 40: "4249", 50: "4624" };
    var actual_price_allinclusive = 449 * x;
    var discount_allinclusive = ((actual_price_allinclusive - price_allinclusive[x]) / actual_price_allinclusive) * 100;
    discount_allinclusive = Math.floor(discount_allinclusive);

    if (discount_allinclusive !== 0){
      document.getElementById("allinclusive_price").innerHTML = "<sup>$</sup><s style=\"color:red;\" >" + actual_price_allinclusive + "</s>" + price_allinclusive[x] + " <span class=\"mo-pricing-interval\">per year</span>";
      document.getElementById("allinclusive_discount").innerHTML = "<div style=\"color:red;\"><b>[ " + discount_allinclusive + " % discount ] </b></div>";
      document.getElementById("allinclusive_discount").style.display = "block";
    }else{
      document.getElementById("allinclusive_price").innerHTML = "<sup>$</sup>" + price_allinclusive[x] + " <span class=\"mo-pricing-interval\">per year</span>";
      document.getElementById("allinclusive_discount").style.display = "none";
    }
  }

}

var coll = document.getElementsByClassName("collapsible");
var i;

for (i = 0; i < coll.length; i++) {
  coll[i].addEventListener("click", function() {
    this.classList.toggle("active");
    var content = this.nextElementSibling;
    if (content.style.display === "block") {
      content.style.display = "none";
    } else {
      content.style.display = "block";
    }
  });
}
